@@ -1,5 +1,5 @@
 // Avisynth v2.5.  Copyright 2002-2009 Ben Rudiak-Gould et al.
-// http://www.avisynth.org
+// http://avisynth.nl
 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -621,10 +621,14 @@ static void convert_uint_limited_c(const BYTE* srcp, BYTE* dstp, int src_rowsize
     // reduce range
     const int shift_bits = source_bitdepth - target_bitdepth;
     const int round = 1 << (shift_bits - 1);
+
+    const int target_max = (1 << target_bitdepth) - 1;
+    constexpr auto target_min = 0;
+
     for (int y = 0; y < src_height; y++)
     {
       for (int x = 0; x < src_width; x++) {
-        dstp0[x] = (srcp0[x] + round) >> shift_bits;  // reduce range
+        dstp0[x] = clamp((srcp0[x] + round) >> shift_bits, target_min, target_max);;  // reduce range
       }
       dstp0 += dst_pitch;
       srcp0 += src_pitch;
@@ -734,18 +738,6 @@ static void convert_float_to_float_c(const BYTE* srcp, BYTE* dstp, int src_rowsi
   bits_conv_constants d;
   get_bits_conv_constants(d, chroma, fulls, fulld, source_bitdepth, target_bitdepth);
 
-#if 0
-  float src_offset = 0;
-
-  if constexpr (/*chroma ||*/ !fulls) {
-    src_offset = d.src_offset;
-  }
-  else {
-    assert(d.src_offset == 0);
-    src_offset = 0; // helps optimizer
-  }
-#endif
-
   for (int y = 0; y < src_height; y++)
   {
     for (int x = 0; x < src_width; x++)
@@ -1270,7 +1262,7 @@ AVSValue __cdecl ConvertBits::Create(AVSValue args, void* user_data, IScriptEnvi
     auto frame0 = clip->GetFrame(0, env);
     const AVSMap* props = env->getFramePropsRO(frame0);
     if (env->propNumElements(props, "_ColorRange") > 0) {
-      ColorRange_src = (int)env->propGetInt(props, "_ColorRange", 0, nullptr); // fixme: range check
+      ColorRange_src = (int)env->propGetIntSaturated(props, "_ColorRange", 0, nullptr);
     }
     else {
       // no param, no frame property -> rgb is full others are limited
